Introduction
============

Schemathesis is a tool for testing your web applications built with Open API or GraphQL specifications.

Installation
------------

We recommend using the latest version of Python. Schemathesis supports Python 3.7 and newer.

Install the most recent Schemathesis version using ``pip``:

.. code-block:: text

  $ pip install schemathesis

Supported API specs
-------------------

We support the following API specifications:

- Swagger 2.0. Python tests + CLI
- Open API 3.0.x. Python tests + CLI
- GraphQL June 2018. Python tests + CLI
